%global mainver %(echo %{version} | cut -d . -f1)
%global minver %(echo %{version} | cut -d . -f2)
%global gittag %(echo r%{mainver}rv%{minver})
%global classname org.bouncycastle.jce.provider.BouncyCastleProvider

Summary:          Bouncy Castle Cryptography APIs for Java
Name:             bouncycastle
Version:          1.78
Release:          1%{?dist}
License:          MIT
URL:              http://www.bouncycastle.org
Source0:          https://github.com/bcgit/bc-java/archive/%{gittag}.tar.gz
Source1:          https://repo1.maven.org/maven2/org/bouncycastle/bcprov-jdk18on/%{version}/bcprov-jdk18on-%{version}.pom
Source2:          https://repo1.maven.org/maven2/org/bouncycastle/bcpkix-jdk18on/%{version}/bcpkix-jdk18on-%{version}.pom
Source3:          https://repo1.maven.org/maven2/org/bouncycastle/bcpg-jdk18on/%{version}/bcpg-jdk18on-%{version}.pom
Source4:          https://repo1.maven.org/maven2/org/bouncycastle/bcmail-jdk18on/%{version}/bcmail-jdk18on-%{version}.pom
Source5:          https://repo1.maven.org/maven2/org/bouncycastle/bctls-jdk18on/%{version}/bctls-jdk18on-%{version}.pom
Source6:          https://repo1.maven.org/maven2/org/bouncycastle/bcutil-jdk18on/%{version}/bcutil-jdk18on-%{version}.pom

BuildArch:        noarch
ExclusiveArch:  %{java_arches} noarch

BuildRequires: jakarta-mail javapackages-local
BuildRequires: aqute-bnd ant ant-junit jakarta-activation1
Requires(post):   javapackages-tools
Requires(postun): javapackages-tools

Provides:         bcprov = %{version}-%{release}

%description
The Bouncy Castle APIs currently consist of the following:

 - A lightweight cryptography API for Java and C#.
 - A provider for the Java Cryptography Extension (JCE) and the Java Cryptography Architecture (JCA).
 - A provider for the Java Secure Socket Extension (JSSE).
 - A clean room implementation of the JCE 1.2.1.
 - A library for reading and writing encoded ASN.1 objects.
 - Lightweight APIs for TLS (RFC 2246, RFC 4346) and DTLS (RFC 6347/ RFC 4347).
 - Generators for Version 1 and Version 3 X.509 certificates, Version 2 CRLs, and PKCS12 files.
 - Generators for Version 2 X.509 attribute certificates.
 - Generators/Processors for S/MIME and CMS (PKCS7/RFC 3852).
 - Generators/Processors for OCSP (RFC 2560).
 - Generators/Processors for TSP (RFC 3161 & RFC 5544).
 - Generators/Processors for CMP and CRMF (RFC 4210 & RFC 4211).
 - Generators/Processors for OpenPGP (RFC 4880).
 - Generators/Processors for Extended Access Control (EAC).
 - Generators/Processors for Data Validation and Certification Server (DVCS) - RFC 3029.
 - Generators/Processors for DNS-based Authentication of Named Entities (DANE).
 - Generators/Processors for RFC 7030 Enrollment over Secure Transport (EST).
 - A signed jar version suitable for JDK 1.4-1.15 and the Sun JCE.

%package pkix
Summary: Bouncy Castle PKIX, CMS, EAC, TSP, PKCS, OCSP, CMP, and CRMF APIs

%description pkix
The Bouncy Castle Java APIs for CMS, PKCS, EAC, TSP, CMP, CRMF, OCSP, and
certificate generation. This jar contains APIs for JDK 1.5 to JDK 1.8. The
APIs can be used in conjunction with a JCE/JCA provider such as the one
provided with the Bouncy Castle Cryptography APIs.

%package pg
Summary: Bouncy Castle OpenPGP API

%description pg
The Bouncy Castle Java API for handling the OpenPGP protocol. The APIs can be
used in conjunction with a JCE/JCA provider such as the one provided with the
Bouncy Castle Cryptography APIs.

%package mail
Summary: Bouncy Castle S/MIME API

%description mail
The Bouncy Castle Java S/MIME APIs for handling S/MIME protocols. The APIs can
be used in conjunction with a JCE/JCA provider such as the one provided with
the Bouncy Castle Cryptography APIs. The JavaMail API and the Java activation
framework will also be needed.

%package tls
Summary: Bouncy Castle JSSE provider and TLS/DTLS API

%description tls
The Bouncy Castle Java APIs for TLS and DTLS, including a provider for the
JSSE.

%package util
Summary: Bouncy Castle ASN.1 Extension and Utility APIs

%description util
The Bouncy Castle Java APIs for ASN.1 extension and utility APIs used to
support bcpkix and bctls.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
API documentation for the Bouncy Castle Cryptography APIs.

%prep
%autosetup -p1 -n bc-java-%{gittag}

find . -type f -name "*.class" -exec rm -f {} \;
find . -type f -name "*.jar" -exec rm -f {} \;

sed -i -e '/<javadoc/aadditionalparam="-Xdoclint:none" encoding="UTF-8" source="1.8"' \
       -e '/<javac/aencoding="UTF-8"' ant/bc+-build.xml
sed -i -e '/target="build-jmail"/d' ant/jdk15+.xml
sed -i -e '/target="build-lw"/d' ant/jdk15+.xml
sed -i -e '/target="javadoc-lw"/d' ant/jdk15+.xml

cp -p %{SOURCE1} bcprov.pom
cp -p %{SOURCE2} bcpkix.pom
cp -p %{SOURCE3} bcpg.pom
cp -p %{SOURCE4} bcmail.pom
cp -p %{SOURCE5} bctls.pom
cp -p %{SOURCE6} bcutil.pom

%build
ant -f ant/jdk15+.xml \
  -Djunit.jar.home=$(build-classpath junit) \
  -Dmail.jar.home=$(build-classpath jakarta-mail/jakarta.mail) \
  -Dactivation.jar.home=$(build-classpath jakarta-activation1/jakarta.activation) \
  -Drelease.debug=true -Dbc.javac.source=1.8 -Dbc.javac.target=1.8 \
  clean build-provider build #test

cat > bnd.bnd <<EOF
-classpath=bcprov.jar,bcutil.jar,bcpkix.jar,bcpg.jar,bcmail.jar,bctls.jar
Export-Package: *;version=%{version}
EOF

for bc in bcprov bcutil bcpkix bcpg bcmail bctls ; do
  bnd wrap -b $bc -v %{version} -p bnd.bnd -o $bc.jar build/artifacts/jdk1.5/jars/$bc-jdk18on-*.jar

  %mvn_file ":$bc-jdk18on" $bc
  %mvn_package ":$bc-jdk18on" $bc
  %mvn_alias ":$bc-jdk18on" "org.bouncycastle:$bc-jdk16" "org.bouncycastle:$bc-jdk15"
  %mvn_artifact $bc.pom $bc.jar
done

%install
install -dm 755 %{buildroot}%{_sysconfdir}/java/security/security.d
touch %{buildroot}%{_sysconfdir}/java/security/security.d/2000-%{classname}

%mvn_install -J build/artifacts/jdk1.5/javadoc

%post
{
  suffix=security/classpath.security
  secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

  for secfile in $secfiles
  do
    [ -f "$secfile" ] || continue

    sed -i '/^security\.provider\./d' "$secfile"

    count=0
    for provider in $(ls /etc/java/security/security.d)
    do
      count=$((count + 1))
      echo "security.provider.${count}=${provider#*-}" >> "$secfile"
    done
  done
} || :

%postun
if [ "$1" -eq 0 ] ; then

  {
    suffix=security/classpath.security
    secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

    for secfile in $secfiles
    do
      [ -f "$secfile" ] || continue

      sed -i '/^security\.provider\./d' "$secfile"

      count=0
      for provider in $(ls /etc/java/security/security.d)
      do
        count=$((count + 1))
        echo "security.provider.${count}=${provider#*-}" >> "$secfile"
      done
    done
  } || :

fi

%files -f .mfiles-bcprov
%license build/artifacts/jdk1.5/bcprov-jdk18on-*/LICENSE.html
%doc docs/ *.html
%{_sysconfdir}/java/security/security.d/2000-%{classname}

%files pkix -f .mfiles-bcpkix
%license build/artifacts/jdk1.5/bcpkix-jdk18on-*/LICENSE.html

%files pg -f .mfiles-bcpg
%license build/artifacts/jdk1.5/bcpg-jdk18on-*/LICENSE.html

%files mail -f .mfiles-bcmail
%license build/artifacts/jdk1.5/bcmail-jdk18on-*/LICENSE.html

%files tls -f .mfiles-bctls
%license build/artifacts/jdk1.5/bctls-jdk18on-*/LICENSE.html

%files util -f .mfiles-bcutil
%license build/artifacts/jdk1.5/bcutil-jdk18on-*/LICENSE.html

%files javadoc -f .mfiles-javadoc
%license LICENSE.html

%changelog
* Fri Sep 20 2024 Upgrade Robot <upbot@opencloudos.tech> - 1.78-1
- Upgrade to version 1.78
- fixed CVE-2024-30171 CVE-2023-33201 CVE-2024-34447

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 25 2023 cunshunxia <cunshunxia@tencent.com> - 1.70-1
- initial build
